#!/usr/bin/perl
use strict;
use warnings;
use Opt::Imistic qw(1);
use Data::Dumper;

print Dumper (\%ARGV);
